<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:java="http://xml.apache.org/xslt/java"
  xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
  xmlns:gsf="http://www.greenstone.org/configformat"
  extension-element-prefixes="java util"
  exclude-result-prefixes="java util gsf">

  <xsl:include href="style.xsl"/>
  <xsl:include href="service-params.xsl"/>
  <xsl:output method="html"/>
  
  <xsl:template name="pageHead">
    <xsl:variable name="docID" select="/page/pageResponse/document/@selectedNode"/>
    <head>
      <title><xsl:for-each select='/page/pageResponse/document/descendant::documentNode[@nodeID=$docID]/ancestor-or-self::documentNode'><xsl:if test='position()!=1'>::</xsl:if><xsl:value-of select="metadataList/metadata[@name='Title']"/></xsl:for-each><xsl:text> </xsl:text></title>
      <xsl:call-template name="css-style"/>
    </head>
  </xsl:template>

  <!-- this is hard coded for GATE, should somehow do it dynamically-->
  <xsl:template name="css-style">
    <style type="text/css">
      <xsl:text disable-output-escaping="yes">
	span.Location {  display:inline; color : red }
	span.Person {  display:inline; color : green }
	span.Organization {  display:inline; color : yellow }
	span.Date {  display:inline; color : blue }
	span.query_term {display: inline; background-color : yellow }
      </xsl:text>
    </style>
  </xsl:template>
  
  <xsl:template match="pageResponse">
    <xsl:variable name="collName"><xsl:value-of select="/page/pageRequest/paramList/param[@name='c']/@value"/></xsl:variable>
    <xsl:call-template name="standardPageBanner">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:call-template>
    <xsl:call-template name="navigationBar">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:call-template>      
    <!-- display the document -->
    <xsl:apply-templates select="document">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:apply-templates>
    <xsl:call-template name="dividerBar"/>
  </xsl:template>
	
  <xsl:template match="document">
    <xsl:param name="collName"/>
    <xsl:call-template name="documentHeading">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:call-template>
    <xsl:call-template name="documentContent">
      <xsl:with-param name="collName" select="$collName"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="documentHeading">
    <xsl:param name="collName"/>
    <xsl:variable name="doCoverImage" select="/page/pageResponse/format/gsf:option[@name='coverImages']/@value"/>
    <xsl:variable name="doTOC" select="/page/pageResponse/format/gsf:option[@name='TOC']/@value"/>
    <xsl:variable name="p.a" select="/page/pageRequest/paramList/param[@name='p.a']/@value"/>
    <xsl:variable name="p.sa" select="/page/pageRequest/paramList/param[@name='p.sa']/@value"/>
    <xsl:variable name="p.s" select="/page/pageRequest/paramList/param[@name='p.s']/@value"/>
    
    <table><tr><td>
	  <a href="{$library_name}?a={$p.a}&amp;sa={$p.sa}&amp;s={$p.s}&amp;c={$collName}&amp;rt=r"><xsl:call-template name="openbookimg"><xsl:with-param name="title">Close this book and return to search/browse</xsl:with-param>
	  </xsl:call-template></a></td>
	<td valign='top'><b><font size="+1">&#160;<xsl:value-of disable-output-escaping="yes" select="documentNode/metadataList/metadata[@name='Title']"/></font></b></td>
      </tr></table>

    <table cellpadding="10" cellspacing="0">
      <tr>
	<td valign="top" align="left">
	  <xsl:if test="string($doCoverImage) != 'false' and (@docType='paged' or @docType='hierarchy')">
	    <xsl:call-template name="coverImage"/>
	    <p/>
	  </xsl:if>
	  
	  <xsl:call-template name="documentButtons">
	    <xsl:with-param name="collName" select="$collName"/>
	  </xsl:call-template>
	  <!--<xsl:call-template name="enrichServices">
	    <xsl:with-param name="collName" select="$collName"/>
	  </xsl:call-template>-->
	</td>
	<xsl:if test="string($doTOC) != 'false'">
	  <td valign="top" align="left">
	    <xsl:call-template name="TOC">
	      <xsl:with-param name="collName" select="$collName"/>
	    </xsl:call-template>
	  </td>
	</xsl:if>
      </tr>
    </table>
  </xsl:template>

  <xsl:template name="coverImage">
    <img><xsl:attribute name='src'><xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>/index/assoc/<xsl:value-of select="metadataList/metadata[@name='archivedir']"/>/cover.jpg</xsl:attribute></img>
  </xsl:template>

  <xsl:template name="documentButtons">
    <xsl:param name="collName"/>
    <xsl:variable name="docID" select="/page/pageRequest/paramList/param[@name='d']/@value"/>
    <xsl:variable name="sib" select="/page/pageRequest/paramList/param[@name='sib']/@value"/>
    <xsl:variable name="ec" select="/page/pageRequest/paramList/param[@name='ec']/@value"/>
    <xsl:variable name="et" select="/page/pageRequest/paramList/param[@name='et']/@value"/>
    <table>
      <tr><td xsl:use-attribute-sets="td-brownbutton">
	  <xsl:choose><xsl:when test="string($et)='1'">
	      <a style="text-decoration:none" href="{$library_name}?a=d&amp;d={$docID}&amp;c={$collName}&amp;sib={$sib}&amp;et=0"><xsl:attribute name="title"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.contract_text_tip')"/></xsl:attribute>
		<b><font color='{$colour-button-text}'><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.contract_text_b')"/></font></b>
	      </a>
	    </xsl:when>
	    <xsl:otherwise>
	  <a style="text-decoration:none" href="{$library_name}?a=d&amp;d={$docID}&amp;c={$collName}&amp;sib={$sib}&amp;et=1"><xsl:attribute name="title"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.expand_text_tip')"/></xsl:attribute>
	    <b><font color='{$colour-button-text}'><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.expand_text_b')"/></font></b>
	  </a>
	    </xsl:otherwise>
	  </xsl:choose>
	</td></tr>
      <tr><td xsl:use-attribute-sets="td-brownbutton">
	  <xsl:choose><xsl:when test="string($ec)='1'">
	      <a style="text-decoration:none" href="{$library_name}?a=d&amp;d={$docID}&amp;c={$collName}&amp;sib={$sib}&amp;ec=0"><xsl:attribute name="title"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.contract_contents_tip')"/></xsl:attribute>
		<b><font color='{$colour-button-text}'><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.contract_contents_b')"/></font></b>
	      </a>
	    </xsl:when>
	    <xsl:otherwise>
	      <a style="text-decoration:none" href="{$library_name}?a=d&amp;d={$docID}&amp;c={$collName}&amp;sib={$sib}&amp;ec=1"><xsl:attribute name="title"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.expand_contents_tip')"/></xsl:attribute>
		<b><font color='{$colour-button-text}'><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'doc.expand_contents_b')"/></font></b>
	      </a>
	    </xsl:otherwise>
	  </xsl:choose>
	</td></tr>
      <tr><td xsl:use-attribute-sets="td-brownbutton">Detach Page</td></tr>
    </table>
  </xsl:template>

  <xsl:template name="TOC">
    <xsl:param name="collName"/>
    <xsl:choose>
      <xsl:when test="@docType='hierarchy'">
	<xsl:call-template name="hierarchicalContents">
	  <xsl:with-param name="collName" select="$collName"/>
	</xsl:call-template>
      </xsl:when>
      <xsl:when test="@docType='paged'">
	<xsl:call-template name="pagedContents">
	  <xsl:with-param name="collName" select="$collName"/>
	</xsl:call-template>
      </xsl:when>
    </xsl:choose>
  </xsl:template>
    
  <xsl:template name="hierarchicalContents">
    <xsl:param name="collName"/>
    <xsl:variable name="oc" select="/page/pageRequest/paramList/param[@name='oc']/@value"/>
    <xsl:variable name="d" select="/page/pageRequest/paramList/param[@name='d']/@value"/>
    <xsl:variable name="sib" select="/page/pageRequest/paramList/param[@name='sib']/@value"/>
    <xsl:if test="documentNode[@nodeID]">
      <table>
	<tr valign='top'><td>
	    <xsl:choose><xsl:when test="string($oc)='0'">
		<a href="{$library_name}?a=d&amp;c={$collName}&amp;d={$d}&amp;sib={$sib}&amp;oc=1"><xsl:call-template name="closedfolderimg"><xsl:with-param name="title">open the table of contents</xsl:with-param></xsl:call-template></a>
	      </xsl:when>
	      <xsl:otherwise><a href="{$library_name}?a=d&amp;c={$collName}&amp;d={$d}&amp;sib={$sib}&amp;oc=0"><xsl:call-template name="openfolderimg"><xsl:with-param name="title">close the table of contents</xsl:with-param></xsl:call-template></a></xsl:otherwise></xsl:choose>
	  </td><td>Table of Contents</td></tr>
	<xsl:if test="string($oc)!='0'">
	  <tr><td></td><td>
	      <table>
		<xsl:for-each select="documentNode/documentNode[@nodeID]">
		  <xsl:apply-templates select='.'><xsl:with-param name="collName" select="$collName"/></xsl:apply-templates>
		</xsl:for-each>
	      </table>
	    </td></tr>
	</xsl:if>
      </table>
    </xsl:if>
  </xsl:template>
  
  <!-- each icon-title pair is a row in a table. children go in a table in another row -->
  <xsl:template match="documentNode">
    <xsl:param name="collName"/>
    <!-- Display the appropriate image, depending on the node type -->
    <tr><td valign="top">
	<a><xsl:attribute name="href"><xsl:value-of select='$library_name'/>?a=d&amp;c=<xsl:value-of select='$collName'/>&amp;d=<xsl:value-of select='@nodeID'/><xsl:if test="documentNode">.pr</xsl:if><xsl:if test="@nodeType='leaf'">&amp;sib=1</xsl:if></xsl:attribute>
	  <xsl:apply-templates select="." mode="displayNodeIcon"/>
	</a>
      </td>
      
      <!-- Display associated title, bolded if the node has content -->
      <td valign="top">
	<xsl:choose>
	  <xsl:when test="nodeContent">
	    <b><xsl:value-of disable-output-escaping="yes" select="metadataList/metadata[@name='Title']"/></b>
	  </xsl:when>
	  <xsl:otherwise>
	    <xsl:value-of disable-output-escaping="yes" select="metadataList/metadata[@name='Title']"/>
	  </xsl:otherwise>
	</xsl:choose>
      </td>
    </tr>
    <!-- Apply recursively to the children of this node -->
    <xsl:if test="documentNode[@nodeID]">
      <tr><td></td><td><table>
	    <xsl:apply-templates select="documentNode[@nodeID]">
	      <xsl:with-param name="collName" select="$collName"/>
	      <!--<xsl:with-param name="depth" select="$depth + 1"/>-->
	    </xsl:apply-templates>
	  </table>
	</td></tr>
    </xsl:if>
  </xsl:template>
  
  <!-- default content is to process any nodeContent elements and print out their text -->
  <xsl:template name="documentContent">
    <xsl:apply-templates select="descendant-or-self::node()/nodeContent"/>
  </xsl:template>
  

  <!-- the actual text/content -->
  <xsl:template match="nodeContent">
    <p/>
    <xsl:for-each select="node()">
      <xsl:choose>
	<xsl:when test="not(name())"><xsl:value-of select="." disable-output-escaping="yes"/></xsl:when>
	<xsl:otherwise><xsl:apply-templates select="."/></xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:template>
  
  <!-- match any link nodes -->
  <xsl:template match="link">
    <xsl:variable name="collName" select="/page/pageRequest/paramList/param[@name='c']/@value"/> 
    <xsl:variable name="actionargs">
      <xsl:choose>
	<xsl:when test="@type='document'">a=d</xsl:when>
	<xsl:when test="@type='query'">a=q&amp;s=<xsl:value-of select="@service"/>&amp;rt=r</xsl:when>
	<xsl:otherwise>
	  p
	</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="serviceargs">
      <xsl:for-each select="param">&amp;s1.<xsl:value-of select="@name"/>=<xsl:value-of select="@value"/></xsl:for-each>
  </xsl:variable>
    <a href="{$library_name}?{$actionargs}&amp;c={$collName}{$serviceargs}"><xsl:value-of disable-output-escaping="yes" select="."/></a>
  </xsl:template>

  <!-- match any annotations and make them span elements -->
  <xsl:template match="annotation">
    <span class="{@type}"><xsl:value-of disable-output-escaping="yes" select="."/></span>
  </xsl:template>
  
  <!-- paged naviagtion : INCOMPLETE!!-->
  <xsl:template name="pagedContents">
    <xsl:param name="collName"/>
    <xsl:variable name="pos" select="nodeStructureInfo/info[@name='siblingPosition']/@value"/>
    <xsl:variable name="length" select="nodeStructureInfo/info[@name='numSiblings']/@value"/>
    <xsl:variable name="children" select="nodeStructureInfo/info[@name='numChildren']/@value"/>
    <table>
      <xsl:choose>
	<xsl:when test="$pos=-1"><!-- a doc -->
	  <tr valign="top">
	    <td align="left">
	    </td>
	    <td align="center"><center>
		<b><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'document.pages', $children)"/></b>
	      </center></td>
	    <td align="right">
	      <a href="{$library_name}?a=d&amp;c={$collName}&amp;d={@selectedNode}.fc"><img src="interfaces/default/images/more.gif" border="0" align="absbottom" /></a>
	    </td>
	  </tr>
	</xsl:when>
	
	<xsl:otherwise> <!-- an internal node -->	  
	  <tr valign="top">
	    <td align="left">
	      <xsl:if test=" not ( $pos = 1 )">
		<a href="{$library_name}?a=d&amp;c={$collName}&amp;d={@selectedNode}.ps"><img src="interfaces/default/images/less.gif" border="0" align="absbottom" /></a>
	      </xsl:if>
	    </td>
	    <td align="center"><center>
		<b><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'document.pageof', concat($pos, ';', $length))"/></b>
	      </center></td>
	    <td align="right">
	      <xsl:if test=" not($pos = $length)">
		<a href="{$library_name}?a=d&amp;c={$collName}&amp;d={@selectedNode}.ns"><img src="interfaces/default/images/more.gif" border="0" align="absbottom" /></a>
	      </xsl:if>
	    </td>
	  </tr>
	</xsl:otherwise>
      </xsl:choose>
      <tr valign="middle">
	<td align='center' valign='top' colspan='3'>
	  <form name="GotoForm" method="get" action="{$library_name}">
	    <input type='hidden' name='a' value='d'/>
	    <input type='hidden' name='c' value='{$collName}'/>
	    <input type='hidden' name='d' value='{@selectedNode}'/>
	    <input type="text" name="gp" size="3" maxlength="4"/>
	    <input type="submit"><xsl:attribute name='value'><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'document.gotopage')"/></xsl:attribute></input>
	  </form>
	</td>
      </tr>
    </table>
  </xsl:template>
  
  <xsl:template name="enrichServices">
    <xsl:param name="collName"/>
    <xsl:variable name="docID" select="/page/pageRequest/paramList/param[@name='d']/@value"/>
    <xsl:for-each select="../serviceList/service">
      <table border='1' cellspacing='0'>
	<tr><td>
	    <p /><xsl:value-of select="displayItem[@name='name']"/><p/>
	    <form name="EnrichForm" method="get" action="{$library_name}">
	      <xsl:apply-templates select="paramList"/>
	      <input type='hidden' name='a' value='d'/>
	      <input type='hidden' name='d' value='{$docID}'/>
	      <input type='hidden' name='c' value='{$collName}'/>
	      <xsl:if test='/page/pageRequest/paramList/param[@name="sib"]'>
		<input type='hidden' name='sib'><xsl:attribute name='value'><xsl:value-of select='/page/pageRequest/paramList/param[@name="sib"]/@value'/></xsl:attribute></input></xsl:if>
	      <input type='hidden' name='s' value='{@name}'/>
	      <input type='hidden' name='ed' value='1'/>
	      <input type="submit"><xsl:attribute name="value"><xsl:value-of select="displayItem[@name='submit']"/></xsl:attribute></input>
	    </form>
	  </td></tr>
      </table>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="paramList" mode="hidden">
    <xsl:for-each select="param">
      <input type='hidden' name='{@name}' value='{@value}'/><xsl:text>
      </xsl:text>
    </xsl:for-each>
  </xsl:template>
  
</xsl:stylesheet>




